<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:java="http://xml.apache.org/xslt/java"
    xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
    xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
    xmlns:gslib="http://www.greenstone.org/skinning"
    xmlns:v-bind="http://vuejs.org"
    xmlns:v-on="http://vuejs.org"
    extension-element-prefixes="java util"
    exclude-result-prefixes="java util">

    <!-- use the 'main' layout -->
    <xsl:import href="layouts/main.xsl"/>

    <xsl:variable name="groupPath"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/></xsl:variable>
    <!-- set page title -->
    <xsl:template name="pageTitle"><gslib:collectionName/></xsl:template>

    <!-- set page breadcrumbs -->
    <xsl:template name="breadcrumbs"><gslib:siteLink/><gslib:rightArrow/>
        <xsl:if test="$groupPath != ''">
            <xsl:for-each select="/page/pageResponse/pathList/group">
                <xsl:sort data-type="number" select="@position" />
                <a>
                    <xsl:attribute name="href"><gslib:groupHref path="{@path}"/></xsl:attribute>				
                    <xsl:attribute name="title"><gslib:groupName path="{@path}"/></xsl:attribute>
                    <gslib:groupName path="{@path}" />
                </a>
                <gslib:rightArrow/>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>

    <!-- the page content -->
    <xsl:template match="/page">
        <xsl:call-template name="audio-transcription" />
    </xsl:template>
    
    <!-- Template for processing audio file uploads -->
    <xsl:template name="audio-transcription">
        <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet" />
        <link href="interfaces/{$interface_name}/style/asr.css" rel="stylesheet" type="text/css" />

        <section id="audio-transcription-container">
            <!-- Used to calculate the character size of our monospace font -->
            <span class="monospace-font-sizer">ngā tama a rangi</span>

            <!-- Contains the file input, transcribe button and transcription progress indicator -->
            <div id="audioUploadContainer" class="audio-file-picker">
                <!-- <button type="button" v-on:click="openFilePicker">
                    <span class="material-icons">&#xE2C6;</span> file_upload
                    <span>Upload Audio Files</span>
                </button>-->

                <div class="text-input-sl" style="cursor: pointer;" v-on:click="openFilePicker">
                    <span class="text-placeholder material-icons" v-if="!anyFiles">&#xe226;</span> <!-- attach_file -->
                    <span class="text-placeholder" v-if="!anyFiles">Select file/s...</span>
                    <span v-if="anyFiles">{{ getFileNameList }}</span>
                </div>

                <input id="audioFileInput" type="file" v-on:input="onFilesChanged"
                       accept="audio/wav" multiple="multiple" v-bind:disabled="isTranscribing" />

                <button style="float: right;" type="submit"
                        v-bind:disabled="!anyFiles || isTranscribing" v-on:click="doTranscription">
                    <span class="material-icons">&#xEA3E;</span> <!-- history_edu -->
                    <span>Transcribe</span>
                </button>

                <progress v-if="isTranscribing" class="indeterminateLoadingBar" />
            </div>
    
            <!-- Contains the audio element and transcription list -->
            <div id="transcriptionsDisplayContainer">

                <audio id="transcriptionAudio">
                    <source id="transcriptionAudioSource" />
                </audio>

                <ul class="transcription__list">
                    <!-- Displays any failed transcriptions -->
                    <li v-for="[id, failure] in failures">
                        <xsl:attribute name="v-bind:class">
                            <xsl:text disable-output-escaping="yes">{ 'transform-slideout': failure.isDeleted }</xsl:text>
                        </xsl:attribute>

                        <div class="transcription__error-container card">
                            <div>
                                Failed to transcribe <i v-if="failure.file">{{ failure.fileName }}</i><br/>
                                <span v-if="failure.message">Reason: {{ failure.message }}</span>
                            </div>
                            
                            <button class="btn-fab theme-flat" v-on:click="removeFailure(id)">
                                <span class="material-icons">&#xE14C;</span> <!-- clear -->
                            </button>
                        </div>
                    </li>

                    <!-- Displays each transcription --> 
                    <li v-for="[id, transcription] in transcriptions">
                        <xsl:attribute name="v-bind:class">
                            <xsl:text disable-output-escaping="yes">{ 'transform-slideout': transcription.isDeleted }</xsl:text>
                        </xsl:attribute>

                        <div class="transcription__container card">
                            <!-- Header containing info and actions for the transcription -->
                            <div class="transcription__header">
                                <span>File: {{ transcription.fileName }}</span>

                                <button class="theme-error" v-on:click="removeTranscription(id)" type="button">
                                    <span class="material-icons">delete</span>
                                    <span>Remove</span>
                                </button>
                            </div>

                            <div class="text-container body0">
                                {{ transcription.transcription }}
                            </div>

                            <div class="transcription__word-list" v-if="transcription.isExpanded">
                                <div class="transcription__word-list__controls">
                                    <button class="btn-fab" v-on:click="playAudioFile(id, -1)" type="button">
                                        <span class="material-icons">play_arrow</span>
                                    </button>

                                    <input type="checkbox" v-model="showCharDisplay" title="Show characters" />

                                    <input type="checkbox" v-model="enableTextEditing" title="Enable text editing" />
                                </div>
                                
                                <ul class="transcription__list">
                                    <li v-if="!showCharDisplay">
                                        <div v-for="word in transcription.words" class="transcription__word-container"
                                            v-on:click="playAudioFile(id, word.startTime)">
                                            <xsl:attribute name="v-bind:class">
                                                <xsl:text disable-output-escaping="yes">{ 'transcription__word-highlight': word.shouldHighlight }</xsl:text>
                                            </xsl:attribute>

                                            <input type="text" v-bind:size="word.word.length - 1" v-model="word.word" class="transcription__word"
                                                v-bind:disabled="!enableTextEditing" />
                                        </div>
                                    </li>
                                    <li v-if="showCharDisplay">
                                        <span v-for="char in getChars(id)" class="transcription__word-container"
                                              v-on:click="playAudioFile(id, char.startTime)">
                                            {{ char.char }}
                                        </span>
                                    </li>
                                </ul>
                            </div>

                            <hr />

                            <button type="button" class="theme-flat" v-on:click="transcription.isExpanded = !transcription.isExpanded">
                                <span class="material-icons" v-if="!transcription.isExpanded">expand_more</span>
                                <span class="material-icons" v-if="transcription.isExpanded">expand_less</span>
                                <span>Playback and Edit</span>
                            </button>
                        </div>
                    </li>
                </ul>
            </div>

            <!-- <div class="audio-slider__container">
                <button type="button" class="btn-fab">
                    <span class="material-icons mdi-xl">&#xE037;</span>
                </button>
                <input type="range" min="0" value="0" class="audio-slider__range" />
                <span class="audio-slider__value">1:23</span>
            </div> -->
        </section>
        
        <!-- TODO: Switch to production version for release builds -->
        <!-- <gsf:script src="https://unpkg.com/vue@next"></gsf:script> -->
        <gsf:script src="interfaces/{$interface_name}/js/asr/Vue.js"></gsf:script>
        <gsf:script src="interfaces/{$interface_name}/js/asr/asr-controller.js" type="module"></gsf:script>
    </xsl:template>

</xsl:stylesheet>  
